Igt-dev Archive on lore.kernel.org
 help / color / mirror / Atom feed
From: Swati Sharma <swati2.sharma@intel.com>
To: igt-dev@lists.freedesktop.org
Subject: [igt-dev] [PATCH i-g-t 1/3] tests: s/igt_is_dsc_supported/igt_is_dsc_supported_by_sink
Date: Wed, 14 Jun 2023 22:24:29 +0530	[thread overview]
Message-ID: <20230614165431.532799-2-swati2.sharma@intel.com> (raw)
In-Reply-To: <20230614165431.532799-1-swati2.sharma@intel.com>

Rename helper.

Signed-off-by: Swati Sharma <swati2.sharma@intel.com>
Reviewed-by: Kamil Konieczny <kamil.konieczny@linux.intel.com>
---
 lib/igt_dsc.c               | 6 +++---
 lib/igt_dsc.h               | 2 +-
 tests/i915/kms_dsc_helper.c | 2 +-
 tests/kms_invalid_mode.c    | 2 +-
 4 files changed, 6 insertions(+), 6 deletions(-)

diff --git a/lib/igt_dsc.h b/lib/igt_dsc.h
index 9608aad4..241fc0ac 100644
--- a/lib/igt_dsc.h
+++ b/lib/igt_dsc.h
@@ -9,7 +9,7 @@
 #include "igt_fb.h"
 #include "igt_kms.h"
 
-bool igt_is_dsc_supported(int drmfd, char *connector_name);
+bool igt_is_dsc_supported_by_sink(int drmfd, char *connector_name);
 bool igt_is_fec_supported(int drmfd, char *connector_name);
 bool igt_is_dsc_enabled(int drmfd, char *connector_name);
 bool igt_is_force_dsc_enabled(int drmfd, char *connector_name);
diff --git a/tests/i915/kms_dsc_helper.c b/tests/i915/kms_dsc_helper.c
index 02d1a484..1adf920b 100644
--- a/tests/i915/kms_dsc_helper.c
+++ b/tests/i915/kms_dsc_helper.c
@@ -55,7 +55,7 @@ void kms_dsc_exit_handler(int sig)
 
 bool check_dsc_on_connector(int drmfd, igt_output_t *output)
 {
-	if (!igt_is_dsc_supported(drmfd, output->name)) {
+	if (!igt_is_dsc_supported_by_sink(drmfd, output->name)) {
 		igt_debug("DSC not supported on connector %s\n",
 			  output->name);
 		return false;
diff --git a/tests/kms_invalid_mode.c b/tests/kms_invalid_mode.c
index ec048305..63da3a1c 100644
--- a/tests/kms_invalid_mode.c
+++ b/tests/kms_invalid_mode.c
@@ -61,7 +61,7 @@ can_bigjoiner(data_t *data)
 		igt_debug("Platform supports uncompressed bigjoiner\n");
 		return true;
 	} else if (intel_display_ver(devid) >= 11) {
-		return igt_is_dsc_supported(data->drm_fd, data->output->name);
+		return igt_is_dsc_supported_by_sink(data->drm_fd, data->output->name);
 	}
 
 	return false;
diff --git a/lib/igt_dsc.c b/lib/igt_dsc.c
index 9e1ab9b1..6cbd8bae 100644
--- a/lib/igt_dsc.c
+++ b/lib/igt_dsc.c
@@ -42,13 +42,13 @@ static int write_dsc_debugfs(int drmfd, char *connector_name, const char *file_n
 }
 
 /*
- * igt_is_dsc_supported:
+ * igt_is_dsc_supported_by_sink:
  * @drmfd: A drm file descriptor
  * @connector_name: Name of the libdrm connector we're going to use
  *
  * Returns: True if DSC is supported for the given connector, false otherwise.
  */
-bool igt_is_dsc_supported(int drmfd, char *connector_name)
+bool igt_is_dsc_supported_by_sink(int drmfd, char *connector_name)
 {
 	return check_dsc_debugfs(drmfd, connector_name, "DSC_Sink_Support: yes");
 }
@@ -42,13 +42,13 @@ static int write_dsc_debugfs(int drmfd, char *connector_name, const char *file_n
  * @connector_name: Name of the libdrm connector we're going to use
  *
- * Returns: True if DSC is supported for the given connector, false otherwise.
+ * Returns: True if DSC is supported for the given connector/sink, false otherwise.
  */
-- 
2.25.1

  reply	other threads:[~2023-06-14 16:55 UTC|newest]

Thread overview: 14+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2023-06-14 16:54 [igt-dev] [PATCH i-g-t v4 0/3] check dsc hardware capability Swati Sharma
2023-06-14 16:54 ` Swati Sharma [this message]
2023-06-14 16:54 ` [igt-dev] [PATCH i-g-t 2/3] tests: s/check_dsc_on_connector/is_dsc_supported_by_sink Swati Sharma
2023-06-14 16:54 ` [igt-dev] [PATCH i-g-t v4 3/3] tests: add igt_is_dsc_supported_by_source() Swati Sharma
2023-06-16  9:32   ` Kamil Konieczny
2023-06-16 13:58     ` Sharma, Swati2
2023-06-14 17:54 ` [igt-dev] ✗ Fi.CI.BAT: failure for check dsc hardware capability (rev3) Patchwork
2023-06-15 16:15 ` [igt-dev] ✗ GitLab.Pipeline: warning for check dsc hardware capability (rev4) Patchwork
2023-06-15 16:41 ` [igt-dev] ✓ Fi.CI.BAT: success " Patchwork
2023-06-15 17:44 ` [igt-dev] ✓ Fi.CI.BAT: success for check dsc hardware capability (rev5) Patchwork
2023-06-15 20:31 ` [igt-dev] ✓ Fi.CI.IGT: success for check dsc hardware capability (rev4) Patchwork
2023-06-15 22:19 ` [igt-dev] ✓ Fi.CI.IGT: success for check dsc hardware capability (rev5) Patchwork
  -- strict thread matches above, loose matches on Subject: below --
2023-05-31  6:54 [igt-dev] [PATCH i-g-t v3 0/3] check dsc hardware capability Swati Sharma
2023-05-31  6:54 ` [igt-dev] [PATCH i-g-t 1/3] tests: s/igt_is_dsc_supported/igt_is_dsc_supported_by_sink Swati Sharma
2023-06-01 13:48   ` Kamil Konieczny

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20230614165431.532799-2-swati2.sharma@intel.com \
    --to=swati2.sharma@intel.com \
    --cc=igt-dev@lists.freedesktop.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox